.. topggpy documentation master file, created by
   sphinx-quickstart on Thu Feb  8 18:32:44 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

###################################
Welcome to topggpy's documentation!
###################################

.. toctree::
   :maxdepth: 1

   api
   whats_new

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
